<a id="readme-top"></a>

[![Contributors][contributors-shield]][contributors-url]
[![Forks][forks-shield]][forks-url]
[![Stargazers][stars-shield]][stars-url]
[![Issues][issues-shield]][issues-url]
[![License][license-shield]][license-url]

<!-- [![LinkedIn][linkedin-shield]][linkedin-url] -->

<br />
<div align="center">
  <a href="https://github.com/Deadbush225/RePhrase">
    <img src="./src/rephraser/Rephraser.png" alt="Logo" width="80" height="80">
  </a>
  <h3 style="font-size: 1.5em" align="center">RePhraser</h3>

  <p align="center">
    The word processor for rephrasing your work from multiple sources
    <br />
    <br />
    <a href="https://github.com/Deadbush225/RePhrase"><strong>Explore the docs »</strong></a>
    <br />
    <a href="https://github.com/Deadbush225/RePhrase#Demo">View Demo</a>
    &middot;
    <a href="https://github.com/Deadbush225/RePhrase/issues/new?labels=bug&template=bug-report---.md">Report Bug</a>
    &middot;
    <a href="https://github.com/Deadbush225/RePhrase/issues/new?labels=enhancement&template=feature-request---.md">Request Feature</a>
  </p>
</div>

## About The Project

RePhraser helps you keep track of what you wrote and what you pasted from other resources like ChatGPT, Wikipedia, and even custom origins/authors.

### Features

💬 Multiple fonts <br>
📄 Rich text editor <br>
🖼️ Image support <br>
👆 Drag-and-drop <br>
📂 Saves and opens in HTML <br>

### Demo

<div align="center"><img src="./docs/demo.gif" width="650"></img></div>

## Installation:

### Requirements:

- [x] python 3.9 or later
- [x] PyQt5 5.15.10 or later

> Recommended: create a virtual environment first

```
pip install git+https://github.com/Deadbush225/RePhrase
```

### Updates:

```
pip install --upgrade git+https://github.com/Deadbush225/RePhrase
```

## Usage:

Go to any terminal and run:

```
python -m rephraser
```

## Other licenses

Icons used in the application are from [Yusuke Kamiyaman](http://p.yusukekamiyamane.com/).

<!-- MARKDOWN LINKS & IMAGES -->
<!-- https://www.markdownguide.org/basic-syntax/#reference-style-links -->

[contributors-shield]: https://img.shields.io/github/contributors/Deadbush225/RePhrase?style=for-the-badge
[contributors-url]: https://github.com/Deadbush225/RePhrase/graphs/contributors
[forks-shield]: https://img.shields.io/github/forks/Deadbush225/RePhrase?style=for-the-badge
[forks-url]: https://github.com/Deadbush225/RePhrase/forks
[stars-shield]: https://img.shields.io/github/stars/Deadbush225/RePhrase?style=for-the-badge
[stars-url]: https://github.com/Deadbush225/RePhrase/stargazers
[issues-shield]: https://img.shields.io/github/issues/Deadbush225/RePhrase?style=for-the-badge
[issues-url]: https://github.com/Deadbush225/RePhrase/issues
[license-shield]: https://img.shields.io/github/license/Deadbush225/RePhrase?style=for-the-badge
[license-url]: https://github.com/Deadbush225/RePhrase/blob/master/LICENSE.txt
[linkedin-shield]: https://img.shields.io/badge/-LinkedIn-black.svg?style=for-the-badge&logo=linkedin&colorB=555
[linkedin-url]: https://www.linkedin.com/in/eliazar-inso-0342b7210/
[product-screenshot]: images/screenshot.png
